==> vtours-computop-payment-service-sdk-0.7.2-a7635a.zip: src/Model/CreditCard/Recurring/Request.php <==
<?php
/**
 *  LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 *  and is private by copyright law - it is NOT Freeware.
 *
 *  Any unauthorized use of this software without a valid license
 *  is a violation of the license agreement and will be prosecuted by
 *  civil and criminal law.
 *
 * @copyright 2021 Lifestyle Webconsulting GmbH
 * @link http://www.life-style.de
 */

namespace Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring;

use Vtours\ComputopPaymentSdk\Model\CreditCard\ThreeDsData;
use Vtours\ComputopPaymentSdk\Model\RequestBase as RequestBase;

/**
 * Class Request
 * @package Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring
 */
class Request extends RequestBase
{
    /**
     * @var string
     */
    private $addressCountry;

    /**
     * @var string|null
     */
    private $cardNumber;

    /**
     * @var string|null
     */
    private $cardExpiryDate;

    /**
     * @var string|null
     */
    private $cardBrand;

    /**
     * @var string|null
     */
    private $cardHolderName;

    /**
     * @var string|null
     */
    private $cardHolderCountry;

    /**
     * @var string|null
     */
    private $cardHolderCity;

    /**
     * @var string|null
     */
    private $schemeReferenceId;

    /**
     * @var ThreeDsData|null
     */
    private $threeDsData;

    /**
     * @return array
     */
    public function jsonSerialize(): array
    {
        $threeDsData = [];
        if (!empty($this->threeDsData)) {
            $threeDsData = [
                'three_ds_protocol_version' => $this->threeDsData->getProtocolVersion(),
                'three_ds_authentication_value' => $this->threeDsData->getAuthenticationValue(),
                'three_ds_eci' => $this->threeDsData->getEci(),
                'three_ds_server_trans_id' => $this->threeDsData->getServerTransId(),
                'three_ds_acs_xid' => $this->threeDsData->getAcsXid(),
                'three_ds_trans_id' => $this->threeDsData->getDsTransId(),
            ];
        }

        return array_filter(array_replace([
            'address_country' => $this->addressCountry,
            'card_number' => $this->cardNumber,
            'card_expiry_date' => $this->cardExpiryDate,
            'card_brand' => $this->cardBrand,
            'card_holder_name' => $this->cardHolderName,
            'card_holder_country' => $this->cardHolderCountry,
            'card_holder_city' => $this->cardHolderCity,
            'scheme_reference_id' => $this->schemeReferenceId,
        ], $threeDsData, parent::jsonSerialize()));

    }

    /**
     * @return string
     */
    public function getAddressCountry(): string
    {
        return $this->addressCountry;
    }

    /**
     * @param string $addressCountry
     * @return Request
     */
    public function setAddressCountry(string $addressCountry): Request
    {
        $this->addressCountry = $addressCountry;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardNumber(): ?string
    {
        return $this->cardNumber;
    }

    /**
     * @param string|null $cardNumber
     * @return Request
     */
    public function setCardNumber(?string $cardNumber): Request
    {
        $this->cardNumber = $cardNumber;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardExpiryDate(): ?string
    {
        return $this->cardExpiryDate;
    }

    /**
     * @param string|null $cardExpiryDate
     * @return Request
     */
    public function setCardExpiryDate(?string $cardExpiryDate): Request
    {
        $this->cardExpiryDate = $cardExpiryDate;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardBrand(): ?string
    {
        return $this->cardBrand;
    }

    /**
     * @param string|null $cardBrand
     * @return Request
     */
    public function setCardBrand(?string $cardBrand): Request
    {
        $this->cardBrand = $cardBrand;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardHolderName(): ?string
    {
        return $this->cardHolderName;
    }

    /**
     * @param string|null $cardHolderName
     * @return Request
     */
    public function setCardHolderName(?string $cardHolderName): Request
    {
        $this->cardHolderName = $cardHolderName;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardHolderCountry(): ?string
    {
        return $this->cardHolderCountry;
    }

    /**
     * @param string|null $cardHolderCountry
     * @return Request
     */
    public function setCardHolderCountry(?string $cardHolderCountry): Request
    {
        $this->cardHolderCountry = $cardHolderCountry;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardHolderCity(): ?string
    {
        return $this->cardHolderCity;
    }

    /**
     * @param string|null $cardHolderCity
     * @return Request
     */
    public function setCardHolderCity(?string $cardHolderCity): Request
    {
        $this->cardHolderCity = $cardHolderCity;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getSchemeReferenceId(): ?string
    {
        return $this->schemeReferenceId;
    }

    /**
     * @param string|null $schemeReferenceId
     * @return Request
     */
    public function setSchemeReferenceId(?string $schemeReferenceId): Request
    {
        $this->schemeReferenceId = $schemeReferenceId;
        return $this;
    }

    /**
     * @return ThreeDsData|null
     */
    public function getThreeDsData(): ?ThreeDsData
    {
        return $this->threeDsData;
    }

    /**
     * @param ThreeDsData|null $threeDsData
     * @return Request
     */
    public function setThreeDsData(?ThreeDsData $threeDsData): Request
    {
        $this->threeDsData = $threeDsData;
        return $this;
    }

}

==> vtours-computop-payment-service-sdk-0.7.3-248491.zip: src/Model/CreditCard/Recurring/Request.php <==
<?php
/**
 *  LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 *  and is private by copyright law - it is NOT Freeware.
 *
 *  Any unauthorized use of this software without a valid license
 *  is a violation of the license agreement and will be prosecuted by
 *  civil and criminal law.
 *
 * @copyright 2021 Lifestyle Webconsulting GmbH
 * @link http://www.life-style.de
 */

namespace Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring;

use Vtours\ComputopPaymentSdk\Model\CreditCard\ThreeDsData;
use Vtours\ComputopPaymentSdk\Model\RequestBase as RequestBase;

/**
 * Class Request
 * @package Vtours\ComputopPaymentSdk\Model\CreditCard\Recurring
 */
class Request extends RequestBase
{
    /**
     * @var float
     */
    private $amount3D;

    /**
     * @var string
     */
    private $addressCountry;

    /**
     * @var string|null
     */
    private $cardNumber;

    /**
     * @var string|null
     */
    private $cardExpiryDate;

    /**
     * @var string|null
     */
    private $cardBrand;

    /**
     * @var string|null
     */
    private $cardHolderName;

    /**
     * @var string|null
     */
    private $cardHolderCountry;

    /**
     * @var string|null
     */
    private $cardHolderCity;

    /**
     * @var string|null
     */
    private $schemeReferenceId;

    /**
     * @var ThreeDsData|null
     */
    private $threeDsData;

    /**
     * @return array
     */
    public function jsonSerialize(): array
    {
        $threeDsData = [];
        if (!empty($this->threeDsData)) {
            $threeDsData = [
                'three_ds_protocol_version' => $this->threeDsData->getProtocolVersion(),
                'three_ds_authentication_value' => $this->threeDsData->getAuthenticationValue(),
                'three_ds_eci' => $this->threeDsData->getEci(),
                'three_ds_server_trans_id' => $this->threeDsData->getServerTransId(),
                'three_ds_acs_xid' => $this->threeDsData->getAcsXid(),
                'three_ds_trans_id' => $this->threeDsData->getDsTransId(),
            ];
        }

        return array_filter(array_replace([
            'amount_3d' => $this->amount3D,
            'address_country' => $this->addressCountry,
            'card_number' => $this->cardNumber,
            'card_expiry_date' => $this->cardExpiryDate,
            'card_brand' => $this->cardBrand,
            'card_holder_name' => $this->cardHolderName,
            'card_holder_country' => $this->cardHolderCountry,
            'card_holder_city' => $this->cardHolderCity,
            'scheme_reference_id' => $this->schemeReferenceId,
        ], $threeDsData, parent::jsonSerialize()));

    }

    /**
     * @return float
     */
    public function getAmount3D(): float
    {
        return $this->amount3D;
    }

    /**
     * @param float $amount3D
     * @return Request
     */
    public function setAmount3D(float $amount3D): Request
    {
        $this->amount3D = $amount3D;
        return $this;
    }

    /**
     * @return string
     */
    public function getAddressCountry(): string
    {
        return $this->addressCountry;
    }

    /**
     * @param string $addressCountry
     * @return Request
     */
    public function setAddressCountry(string $addressCountry): Request
    {
        $this->addressCountry = $addressCountry;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardNumber(): ?string
    {
        return $this->cardNumber;
    }

    /**
     * @param string|null $cardNumber
     * @return Request
     */
    public function setCardNumber(?string $cardNumber): Request
    {
        $this->cardNumber = $cardNumber;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardExpiryDate(): ?string
    {
        return $this->cardExpiryDate;
    }

    /**
     * @param string|null $cardExpiryDate
     * @return Request
     */
    public function setCardExpiryDate(?string $cardExpiryDate): Request
    {
        $this->cardExpiryDate = $cardExpiryDate;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardBrand(): ?string
    {
        return $this->cardBrand;
    }

    /**
     * @param string|null $cardBrand
     * @return Request
     */
    public function setCardBrand(?string $cardBrand): Request
    {
        $this->cardBrand = $cardBrand;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardHolderName(): ?string
    {
        return $this->cardHolderName;
    }

    /**
     * @param string|null $cardHolderName
     * @return Request
     */
    public function setCardHolderName(?string $cardHolderName): Request
    {
        $this->cardHolderName = $cardHolderName;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardHolderCountry(): ?string
    {
        return $this->cardHolderCountry;
    }

    /**
     * @param string|null $cardHolderCountry
     * @return Request
     */
    public function setCardHolderCountry(?string $cardHolderCountry): Request
    {
        $this->cardHolderCountry = $cardHolderCountry;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getCardHolderCity(): ?string
    {
        return $this->cardHolderCity;
    }

    /**
     * @param string|null $cardHolderCity
     * @return Request
     */
    public function setCardHolderCity(?string $cardHolderCity): Request
    {
        $this->cardHolderCity = $cardHolderCity;
        return $this;
    }

    /**
     * @return string|null
     */
    public function getSchemeReferenceId(): ?string
    {
        return $this->schemeReferenceId;
    }

    /**
     * @param string|null $schemeReferenceId
     * @return Request
     */
    public function setSchemeReferenceId(?string $schemeReferenceId): Request
    {
        $this->schemeReferenceId = $schemeReferenceId;
        return $this;
    }

    /**
     * @return ThreeDsData|null
     */
    public function getThreeDsData(): ?ThreeDsData
    {
        return $this->threeDsData;
    }

    /**
     * @param ThreeDsData|null $threeDsData
     * @return Request
     */
    public function setThreeDsData(?ThreeDsData $threeDsData): Request
    {
        $this->threeDsData = $threeDsData;
        return $this;
    }

}
